Single line status updates with minimal update sequences.


*Latest release 20200229*:
Upd: can now be used as a context manager, clearing the line on exit.
Upd.without is now a context manager, returning the older state, and accepting an optional inner state (default "").
Upd is now a singleton factory, obsoleting upd_for.
Upd.nl: use "insert line above" mode if supported.

Single line status updates with minimal update sequences.

This is available as an output mode in `cs.logutils`.

Example:

    with Upd() as U:
        for filename in filenames:
            U.out(filename)
            ... process filename ...
            upd.nl('an informational line')

## Function `cleanupAtExit()`

Cleanup function called at programme exit to clear the status line.

## Function `Upd(stream)`

Factory for `Upd` singletons keyed by the id of their backend.

## Function `upd_for(stream)`

Factory for `Upd` singletons keyed by the id of their backend.



# Release Log

*Release 20200229*:
Upd: can now be used as a context manager, clearing the line on exit.
Upd.without is now a context manager, returning the older state, and accepting an optional inner state (default "").
Upd is now a singleton factory, obsoleting upd_for.
Upd.nl: use "insert line above" mode if supported.

*Release 20181108*:
Documentation improvements.

*Release 20170903*:
New function upd_for(stream) returning singleton Upds.
Drop noStrip keyword argument/mode - always strip trailing whitespace.

*Release 20160828*:
Use "install_requires" instead of "requires" in DISTINFO.
Add Upd.flush method.
Upd.out: fix longstanding trailing text erasure bug.
Upd.nl,out: accept optional positional parameters, use with %-formatting if supplied, just like logging.

*Release 20150118*:
metadata fix

*Release 20150116*:
Initial PyPI release.
